@@ -1,5 +1,5 @@
 import os
-from pm4py.objects.log.importer.parquet import factory as parquet_importer
+from pm4pydistr.util.parquet_importer import importer as parquet_importer
 from collections import Counter
 from pm4py.algo.discovery.dfg.adapters.pandas import df_statistics
 from pm4py.algo.filtering.pandas.end_activities import end_activities_filter
@@ -958,7 +958,7 @@ def correlation_miner(path, log_name, managed_logs, parameters=None):
     complete_timestamp = parameters["complete_timestamp"] if "complete_timestamp" in parameters else DEFAULT_TIMESTAMP_KEY
     start_timestamp = parameters["start_timestamp"] if "start_timestamp" in parameters else DEFAULT_TIMESTAMP_KEY
 
-    from pm4py.algo.discovery.correlation_mining.versions import classic
+    from pm4py.algo.discovery.correlation_mining.variants import classic
 
     no_samples = parameters[PARAMETER_NO_SAMPLES] if PARAMETER_NO_SAMPLES in parameters else DEFAULT_MAX_NO_SAMPLES
     use_transition = parameters[
