@@ -721,6 +721,9 @@ def perform_alignments():
         max_align_time_trace = content["max_align_time_trace"]
         align_variant = content["align_variant"]
         classic_alignments_variant = content["classic_alignments_variant"]
+        tree_align_variant = content["tree_align_variant"]
+        petri_conversion_version = content["petri_conversion_version"]
+        require_ilp_computation = content["require_ilp_computation"]
 
         if keyphrase == configuration.KEYPHRASE:
             parameters = {}
@@ -728,6 +731,9 @@ def perform_alignments():
             parameters["max_align_time_trace"] = max_align_time_trace
             parameters["align_variant"] = align_variant
             parameters["classic_alignments_variant"] = classic_alignments_variant
+            parameters["tree_align_variant"] = tree_align_variant
+            parameters["petri_conversion_version"] = petri_conversion_version
+            parameters["require_ilp_computation"] = require_ilp_computation
 
             align = slave.perform_alignments(petri_string, var_list, parameters=parameters)
 
